@@ -12,6 +12,7 @@ use IO::Socket::IP;
 use Time::HiRes ();
 use Storable qw();
 use POSIX qw();
+use File::Spec ();
 use if $^O eq "MSWin32",'Win32::Process';
 use if $^O eq "MSWin32",'Win32';
 use base qw(Mojo::Weixin::Util Mojo::Weixin::Request);
@@ -27,8 +28,6 @@ has auth     => undef;
 has server =>  sub { Mojo::Weixin::Server->new };
 has listen => sub { [{host=>"0.0.0.0",port=>2000},] };
 
-has keep_cookie => 0;
-has cookie_path => undef;
 has http_debug          => sub{$ENV{MOJO_WEIXIN_CONTROLLER_HTTP_DEBUG} || 0 } ;
 has ua_debug            => sub{$_[0]->http_debug};
 has ua_debug_req_body   => sub{$_[0]->ua_debug};
@@ -48,6 +47,8 @@ has ua  => sub {
 };
 
 has tmpdir              => sub {File::Spec->tmpdir();};
+has keep_cookie         => 0;
+has cookie_path         => sub {File::Spec->catfile($_[0]->tmpdir,join('','mojo_weixin_controller_cookie','.dat'))};
 has pid_path            => sub {File::Spec->catfile($_[0]->tmpdir,join('','mojo_weixin_controller_process','.pid'))};
 has backend_path        => sub {File::Spec->catfile($_[0]->tmpdir,join('','mojo_weixin_controller_backend','.dat'))};
 has template_path        => sub {File::Spec->catfile($_[0]->tmpdir,join('','mojo_weixin_controller_template','.pl'))};
@@ -234,6 +235,14 @@ sub start_client {
     $ENV{MOJO_WEIXIN_PLUGIN_OPENWX_PORT} = $backend_port;
     $ENV{MOJO_WEIXIN_PLUGIN_OPENWX_POST_API} = $post_api;
     $ENV{MOJO_WEIXIN_PLUGIN_OPENWX_POLL_API} = $poll_api;
+
+    $ENV{MOJO_WEIXIN_LOG_PATH} = $self->log_path;
+    $ENV{MOJO_WEIXIN_LOG_ENCODING} = $self->log_encoding;
+    $ENV{MOJO_WEIXIN_LOG_CONSOLE} = $self->log_console;
+    $ENV{MOJO_WEIXIN_DISABLE_COLOR} = $self->disable_color;
+    $ENV{MOJO_WEIXIN_HTTP_DEBUG} = $self->http_debug;
+    $ENV{MOJO_WEIXIN_LOG_LEVEL} = $self->log_level;
+
     $ENV{MOJO_WEIXIN_TMPDIR} = $self->tmpdir if not defined $ENV{MOJO_WEIXIN_TMPDIR};
     $ENV{MOJO_WEIXIN_STATE_PATH} = File::Spec->catfile($ENV{MOJO_WEIXIN_TMPDIR},join('','mojo_weixin_state_',$ENV{MOJO_WEIXIN_ACCOUNT},'.json')) if not defined $ENV{MOJO_WEIXIN_STATE_PATH};
     $ENV{MOJO_WEIXIN_QRCODE_PATH} = File::Spec->catfile($ENV{MOJO_WEIXIN_TMPDIR},join('','mojo_weixin_qrcode_',$ENV{MOJO_WEIXIN_ACCOUNT},'.jpg')) if not defined $ENV{MOJO_WEIXIN_QRCODE_PATH};
